@@ -1367,7 +1367,7 @@ L<Qui Lab wiki page|http://diverge.hunter.cuny.edu/labwiki/Bioutils>
 
 =item *
 
-L<Github project wiki page|https://github.com/bioperl/p5-bprwrapper>
+L<Github project wiki page|https://github.com/bioperl/p5-bpwrapper>
 
 =back
 
